<?php
/*
 * @package swp-portfolio
 * @since 1.0.0
*/
if (!class_exists('Swp_Portfolio_Custom_Post_Type')) {
    class Swp_Portfolio_Custom_Post_Type
    {

        private static $instance;

        private $singular_name      = 'Portfolio';
        private $plural_name               = 'Portfolios';

        function __construct()
        {
            $this->singular_name = swp_portfolio_get_option('singular_name', 'Portfolio');
            $this->plural_name   = swp_portfolio_get_option('plural_name', 'Portfolios');
            add_action('init', array($this, 'create_post_type'));
        }

        /**
         * getInstance();
         * @since 1.0.0
         * */
        public static function getInstance()
        {
            if (null == self::$instance) {
                self::$instance = new self();
            }
            return self::$instance;
        }

        function create_post_type()
        {
            $labels = array(
                'name'                  => esc_html__($this->plural_name,  'swp-portfolio'),
                'singular_name'         => esc_html__($this->singular_name,  'swp-portfolio'),
                'menu_name'             => esc_html__($this->plural_name, 'swp-portfolio'), // Menu name
                'name_admin_bar'        => esc_html__($this->singular_name, 'swp-portfolio'), // Admin Bar
                'add_new'               => esc_html__('Add New ' . $this->singular_name, 'swp-portfolio'), // Add New button
                'add_new_item'          => esc_html__('Add New ' . $this->singular_name, 'swp-portfolio'), // Add New item
                'new_item'              => esc_html__('New ' . $this->singular_name, 'swp-portfolio'), // New item
                'edit_item'             => esc_html__('Edit ' . $this->singular_name, 'swp-portfolio'), // Edit item
                'view_item'             => esc_html__('View ' . $this->singular_name, 'swp-portfolio'), // View item
                'all_items'             => esc_html__('All ' . $this->plural_name, 'swp-portfolio'), // All items
                'search_items'          => esc_html__('Search ' . $this->plural_name, 'swp-portfolio'), // Search items
                'parent_item_colon'     => esc_html__('Parent : ' . $this->singular_name, 'swp-portfolio'), // Parent item
                'not_found'             => esc_html__('No ' . $this->plural_name . ' found.', 'swp-portfolio'), // Not found
                'not_found_in_trash'    => esc_html__('No ' . $this->plural_name . ' found in Trash.', 'swp-portfolio'), // Not found in Trash
                'featured_image'        => esc_html__($this->singular_name . ' Image', 'swp-portfolio'), // Featured Image
                'set_featured_image'    => esc_html__('Set ' . $this->singular_name . ' image', 'swp-portfolio'), // Set Featured Image
                'remove_featured_image' => esc_html__('Remove ' . $this->singular_name . ' image', 'swp-portfolio'), // Remove Featured Image
                'use_featured_image'    => esc_html__('Use as ' . $this->singular_name . ' image', 'swp-portfolio'), // Use Featured Image
            );


            register_post_type(
                'portfolio',
                array(
                    'labels'             => $labels,
                    'public'             => true,
                    'supports'            => array('title', 'editor', 'thumbnail', 'author'),
                    'hierarchical'       => false,
                    'rewrite'            => array('slug' => 'portfolio'),
                    'menu_icon'          => 'dashicons-images-alt2',
                    'has_archive' => true,
                )
            );
        }
    } // end class


    if (class_exists('Swp_Portfolio_Custom_Post_Type')) {
        Swp_Portfolio_Custom_Post_Type::getInstance();
    }
} //endif 
